@@ -18,7 +18,7 @@
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include "inflationcpibond.hpp"
+#include "toplevelfixture.hpp"
 #include "utilities.hpp"
 #include <ql/indexes/inflation/ukrpi.hpp>
 #include <ql/time/calendars/unitedkingdom.hpp>
@@ -41,18 +41,18 @@
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
 
-#include <iostream>
+BOOST_FIXTURE_TEST_SUITE(QuantLibTests, TopLevelFixture)
 
-namespace inflation_cpi_bond_test {
+BOOST_AUTO_TEST_SUITE(InflationCPIBondTests)
 
-    struct Datum {
-        Date date;
-        Rate rate;
-    };
+struct Datum {
+    Date date;
+    Rate rate;
+};
 
-    typedef BootstrapHelper<ZeroInflationTermStructure> Helper;
+typedef BootstrapHelper<ZeroInflationTermStructure> Helper;
 
-    std::vector<ext::shared_ptr<Helper> > makeHelpers(
+std::vector<ext::shared_ptr<Helper> > makeHelpers(
         const std::vector<Datum>& iiData,
         const ext::shared_ptr<ZeroInflationIndex>& ii,
         const Period& observationLag,
@@ -61,120 +61,111 @@ namespace inflation_cpi_bond_test {
         const DayCounter& dc,
         const Handle<YieldTermStructure>& yTS) {
 
-        std::vector<ext::shared_ptr<Helper> > instruments;
-        for (Datum datum : iiData) {
-            Date maturity = datum.date;
-            Handle<Quote> quote(ext::shared_ptr<Quote>(
+    std::vector<ext::shared_ptr<Helper> > instruments;
+    for (Datum datum : iiData) {
+        Date maturity = datum.date;
+        Handle<Quote> quote(ext::shared_ptr<Quote>(
                                 new SimpleQuote(datum.rate/100.0)));
-            ext::shared_ptr<Helper> h(new ZeroCouponInflationSwapHelper(
+        ext::shared_ptr<Helper> h(new ZeroCouponInflationSwapHelper(
                 quote, observationLag, maturity, calendar, bdc, dc, ii, CPI::AsIndex, yTS));
-            instruments.push_back(h);
-        }
-        return instruments;
+        instruments.push_back(h);
     }
-
-
-    struct CommonVars {
-    
-        Calendar calendar;
-        BusinessDayConvention convention;
-        Date evaluationDate;
-        Period observationLag;
-        DayCounter dayCounter;
-
-        ext::shared_ptr<UKRPI> ii;
-
-        RelinkableHandle<YieldTermStructure> yTS;
-        RelinkableHandle<ZeroInflationTermStructure> cpiTS;
-
-        // cleanup
-
-        SavedSettings backup;
-        IndexHistoryCleaner cleaner;
-
-        // setup
-        CommonVars() {
-            // usual setup
-            calendar = UnitedKingdom();
-            convention = ModifiedFollowing;
-            Date today(25, November, 2009);
-            evaluationDate = calendar.adjust(today);
-            Settings::instance().evaluationDate() = evaluationDate;
-            dayCounter = ActualActual(ActualActual::ISDA);
-
-            Date from(20, July, 2007);
-            Date to(20, November, 2009);
-            Schedule rpiSchedule =
-                MakeSchedule().from(from).to(to)
-                .withTenor(1*Months)
-                .withCalendar(UnitedKingdom())
-                .withConvention(ModifiedFollowing);
-
-            ii = ext::make_shared<UKRPI>(cpiTS);
-
-            Real fixData[] = {
-                206.1, 207.3, 208.0, 208.9, 209.7, 210.9,
-                209.8, 211.4, 212.1, 214.0, 215.1, 216.8,
-                216.5, 217.2, 218.4, 217.7, 216,
-                212.9, 210.1, 211.4, 211.3, 211.5,
-                212.8, 213.4, 213.4, 213.4, 214.4
-            };
-            for (Size i=0; i<LENGTH(fixData); ++i) {
-                ii->addFixing(rpiSchedule[i], fixData[i]);
-            }
-
-            yTS.linkTo(ext::shared_ptr<YieldTermStructure>(
-                          new FlatForward(evaluationDate, 0.05, dayCounter)));
-
-            // now build the zero inflation curve
-            observationLag = Period(2,Months);
-
-            std::vector<Datum> zciisData = {
-                { Date(25, November, 2010), 3.0495 },
-                { Date(25, November, 2011), 2.93 },
-                { Date(26, November, 2012), 2.9795 },
-                { Date(25, November, 2013), 3.029 },
-                { Date(25, November, 2014), 3.1425 },
-                { Date(25, November, 2015), 3.211 },
-                { Date(25, November, 2016), 3.2675 },
-                { Date(25, November, 2017), 3.3625 },
-                { Date(25, November, 2018), 3.405 },
-                { Date(25, November, 2019), 3.48 },
-                { Date(25, November, 2021), 3.576 },
-                { Date(25, November, 2024), 3.649 },
-                { Date(26, November, 2029), 3.751 },
-                { Date(27, November, 2034), 3.77225 },
-                { Date(25, November, 2039), 3.77 },
-                { Date(25, November, 2049), 3.734 },
-                { Date(25, November, 2059), 3.714 },
-            };
-
-            std::vector<ext::shared_ptr<Helper> > helpers =
-                makeHelpers(zciisData, ii,
-                            observationLag, calendar, convention, dayCounter, yTS);
-
-            Rate baseZeroRate = zciisData[0].rate/100.0;
-            cpiTS.linkTo(ext::shared_ptr<ZeroInflationTermStructure>(
-                  new PiecewiseZeroInflationCurve<Linear>(
-                         evaluationDate, calendar, dayCounter, observationLag,
-                         ii->frequency(), baseZeroRate, helpers)));
-        }
-
-        // teardown
-        ~CommonVars() {
-            // break circular references and allow curves to be destroyed
-            cpiTS.linkTo(ext::shared_ptr<ZeroInflationTermStructure>());
-        }
-    };
-
+    return instruments;
 }
 
 
-void InflationCPIBondTest::testCleanPrice() {
-    IndexManager::instance().clearHistories();
+struct CommonVars { // NOLINT(cppcoreguidelines-special-member-functions)
+    
+    Calendar calendar;
+    BusinessDayConvention convention;
+    Date evaluationDate;
+    Period observationLag;
+    DayCounter dayCounter;
+
+    ext::shared_ptr<UKRPI> ii;
+
+    RelinkableHandle<YieldTermStructure> yTS;
+    RelinkableHandle<ZeroInflationTermStructure> cpiTS;
+
+    // setup
+    CommonVars() {
+        // usual setup
+        calendar = UnitedKingdom();
+        convention = ModifiedFollowing;
+        Date today(25, November, 2009);
+        evaluationDate = calendar.adjust(today);
+        Settings::instance().evaluationDate() = evaluationDate;
+        dayCounter = ActualActual(ActualActual::ISDA);
+
+        Date from(20, July, 2007);
+        Date to(20, November, 2009);
+        Schedule rpiSchedule =
+            MakeSchedule().from(from).to(to)
+            .withTenor(1*Months)
+            .withCalendar(UnitedKingdom())
+            .withConvention(ModifiedFollowing);
+
+        ii = ext::make_shared<UKRPI>(cpiTS);
+
+        Real fixData[] = {
+            206.1, 207.3, 208.0, 208.9, 209.7, 210.9,
+            209.8, 211.4, 212.1, 214.0, 215.1, 216.8,
+            216.5, 217.2, 218.4, 217.7, 216,
+            212.9, 210.1, 211.4, 211.3, 211.5,
+            212.8, 213.4, 213.4, 213.4, 214.4
+        };
+        for (Size i=0; i<LENGTH(fixData); ++i) {
+            ii->addFixing(rpiSchedule[i], fixData[i]);
+        }
+
+        yTS.linkTo(ext::shared_ptr<YieldTermStructure>(
+                          new FlatForward(evaluationDate, 0.05, dayCounter)));
+
+        // now build the zero inflation curve
+        observationLag = Period(2,Months);
+
+        std::vector<Datum> zciisData = {
+            { Date(25, November, 2010), 3.0495 },
+            { Date(25, November, 2011), 2.93 },
+            { Date(26, November, 2012), 2.9795 },
+            { Date(25, November, 2013), 3.029 },
+            { Date(25, November, 2014), 3.1425 },
+            { Date(25, November, 2015), 3.211 },
+            { Date(25, November, 2016), 3.2675 },
+            { Date(25, November, 2017), 3.3625 },
+            { Date(25, November, 2018), 3.405 },
+            { Date(25, November, 2019), 3.48 },
+            { Date(25, November, 2021), 3.576 },
+            { Date(25, November, 2024), 3.649 },
+            { Date(26, November, 2029), 3.751 },
+            { Date(27, November, 2034), 3.77225 },
+            { Date(25, November, 2039), 3.77 },
+            { Date(25, November, 2049), 3.734 },
+            { Date(25, November, 2059), 3.714 },
+        };
+
+        std::vector<ext::shared_ptr<Helper> > helpers =
+            makeHelpers(zciisData, ii,
+                        observationLag, calendar, convention, dayCounter, yTS);
+
+        Rate baseZeroRate = zciisData[0].rate/100.0;
+        cpiTS.linkTo(ext::shared_ptr<ZeroInflationTermStructure>(
+                  new PiecewiseZeroInflationCurve<Linear>(
+                         evaluationDate, calendar, dayCounter, observationLag,
+                         ii->frequency(), baseZeroRate, helpers)));
+    }
+
+    // teardown
+    ~CommonVars() {
+        // break circular references and allow curves to be destroyed
+        cpiTS.linkTo(ext::shared_ptr<ZeroInflationTermStructure>());
+    }
+};
+
+
+BOOST_AUTO_TEST_CASE(testCleanPrice) {
+    BOOST_TEST_MESSAGE("Checking cached pricers for CPI bond...");
 
-    using namespace inflation_cpi_bond_test;
-  
     CommonVars common;
 
     Real notional = 1000000.0;
@@ -204,13 +195,21 @@ void InflationCPIBondTest::testCleanPrice() {
                  observationInterpolation, fixedSchedule,
                  fixedRates, fixedDayCount, fixedPaymentConvention);
 
-    ext::shared_ptr<DiscountingBondEngine> engine(
-                                 new DiscountingBondEngine(common.yTS));
+    auto engine = ext::make_shared<DiscountingBondEngine>(common.yTS);
     bond.setPricingEngine(engine);
 
-    Real storedPrice = 383.01816406;
-    Real calculated = bond.cleanPrice();
+    Real storedPrice = 384.71666770;
+    Real calculated = bond.dirtyPrice();
     Real tolerance = 1.0e-8;
+    if (std::fabs(calculated-storedPrice) > tolerance) {
+        BOOST_FAIL("failed to reproduce expected CPI-bond dirty price"
+                   << std::fixed << std::setprecision(12)
+                   << "\n  expected:   " << storedPrice
+                   << "\n  calculated: " << calculated);
+    }
+
+    storedPrice = 383.04297558;
+    calculated = bond.cleanPrice();
     if (std::fabs(calculated-storedPrice) > tolerance) {
         BOOST_FAIL("failed to reproduce expected CPI-bond clean price"
                    << std::fixed << std::setprecision(12)
@@ -219,11 +218,8 @@ void InflationCPIBondTest::testCleanPrice() {
     }
 }
 
-
-void InflationCPIBondTest::testCPILegWithoutBaseCPI() {
-    IndexManager::instance().clearHistories();
-
-    using namespace inflation_cpi_bond_test;
+BOOST_AUTO_TEST_CASE(testCPILegWithoutBaseCPI) {
+    BOOST_TEST_MESSAGE("Checking CPI leg with or without explicit base CPI fixing...");
 
     CommonVars common;
 
@@ -292,7 +288,7 @@ void InflationCPIBondTest::testCPILegWithoutBaseCPI() {
                    << "\n clean npv of leg with explicit baseCPI: " << cleanPriceWithBaseCPI);
     }
     // Compare to expected price
-    Real storedPrice = 383.01816406;
+    Real storedPrice = 383.04297558;
     if (std::fabs(cleanPriceWithBaseDate - storedPrice) > tolerance) {
         BOOST_FAIL("failed to reproduce expected CPI-bond clean price"
                    << std::fixed << std::setprecision(12) << "\n  expected:   " << storedPrice
@@ -300,11 +296,6 @@ void InflationCPIBondTest::testCPILegWithoutBaseCPI() {
     }
 }
 
-test_suite* InflationCPIBondTest::suite() {
-    auto* suite = BOOST_TEST_SUITE("CPI bond tests");
-
-    suite->add(QUANTLIB_TEST_CASE(&InflationCPIBondTest::testCleanPrice));
-    suite->add(QUANTLIB_TEST_CASE(&InflationCPIBondTest::testCPILegWithoutBaseCPI));
-    return suite;
-}
+BOOST_AUTO_TEST_SUITE_END()
 
+BOOST_AUTO_TEST_SUITE_END()
